package
Version:
v0.0.0-...-f8c425d
Opens a new window with list of versions in this module.
Published: May 12, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Brands struct {
BrandId int `json:"brand_id"`
BrandName string `json:"brand_name"`
BrandProduct []int `json:"brand_product"`
}
type Credentials struct {
Username string `json:"username"`
Password string `json:"password"`
}
type Products struct {
ProductId int `json:"product_id"`
ProductName string `json:"product_name"`
ProductBrand Brands `json:"product_brand"`
ProductPrice int `json:"product_price"`
ProductStatus bool `json:"product_status"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.